﻿using System.ComponentModel;
using System.Collections.ObjectModel;

namespace RadTreeListView_WPF
{
	/// <summary>
	/// A football club.
	/// </summary>
	public class Club : INotifyPropertyChanged
	{
		public event PropertyChangedEventHandler PropertyChanged;

		private string name;
		private string country;
		private int number;
		private bool isChampion;
		private ObservableCollection<Player> players;

		public string Name
		{
			get
			{
				return this.name;
			}
			set
			{
				if (value != this.name)
				{
					this.name = value;
					this.OnPropertyChanged("Name");
				}
			}
		}

		public string Country
		{
			get
			{
				return this.country;
			}
			set
			{
				if (value != this.country)
				{
					this.country = value;
					this.OnPropertyChanged("Country");
				}
			}
		}

		public int Number
		{
			get
			{
				return this.number;
			}
			set
			{
				if (value != this.number)
				{
					this.number = value;
					this.OnPropertyChanged("Number");
				}
			}
		}

		public bool IsChampion
		{
			get
			{
				return this.isChampion;
			}
			set
			{
				if (value != this.isChampion)
				{
					this.isChampion = value;
					this.OnPropertyChanged("IsChampion");
				}
			}
		}

		public ObservableCollection<Player> Players
		{
			get
			{
				if (null == this.players)
				{
					this.players = new ObservableCollection<Player>();
				}

				return this.players;
			}
		}

		public Club()
		{
		}

		public Club(string name, string country, int number, bool isChampion)
		{
			this.name = name;
			this.country = country;
			this.number = number;
			this.isChampion = isChampion;
		}

		public Club(string name, string country, int number, bool isChampion, ObservableCollection<Player> players)
		: this(name, country, number, isChampion)
		{
			this.players = players;
		}

		protected virtual void OnPropertyChanged(PropertyChangedEventArgs args)
		{
			PropertyChangedEventHandler handler = this.PropertyChanged;
			if (handler != null)
			{
				handler(this, args);
			}
		}

		private void OnPropertyChanged(string propertyName)
		{
			this.OnPropertyChanged(new PropertyChangedEventArgs(propertyName));
		}

		public override string ToString()
		{
			return this.Name;
		}

		public static ObservableCollection<Club> GetClubs()
		{
			ObservableCollection<Club> clubs = new ObservableCollection<Club>();
			Club club;

			// Liverpool
			club = new Club("Liverpool", "UK", 100, true);
			club.Players.Add(new Player("Pepe Reina", 25, "Spain", 1, false));
			club.Players.Add(new Player("Jamie Carragher", 23, "England", 2, true));
			club.Players.Add(new Player("Steven Gerrard", 8, "England", 3, false));
			club.Players.Add(new Player("Fernando Torres", 9, "Spain", 4, true));
			clubs.Add(club);

			// Manchester Utd.
			club = new Club("Manchester Utd.", "UK", 233, false);
			club.Players.Add(new Player("Edwin van der Sar", 1, "Netherlands", 5, true));
			club.Players.Add(new Player("Rio Ferdinand", 5, "England", 1, false));
			club.Players.Add(new Player("Ryan Giggs", 11, "Wales", 2, true));
			club.Players.Add(new Player("Wayne Rooney", 10, "England", 3, false));
			clubs.Add(club);

			// Chelsea
			club = new Club("Chelsea", "UK", 7878, true);
			club.Players.Add(new Player("Petr Čech", 1, "Czech Republic", 4, false));
			club.Players.Add(new Player("John Terry", 26, "England", 5, true));
			club.Players.Add(new Player("Frank Lampard", 8, "England", 1, false));
			club.Players.Add(new Player("Nicolas Anelka", 39, "France", 2, true));
			clubs.Add(club);

			// Arsenal
			club = new Club("Arsenal", "UK", -232, false);
			club.Players.Add(new Player("Manuel Almunia", 1, "Spain", 5, false));
			club.Players.Add(new Player("Gaël Clichy", 22, "France", 3, false));
			club.Players.Add(new Player("Cesc Fàbregas", 4, "Spain", 1, false));
			club.Players.Add(new Player("Robin van Persie", 11, "Netherlands", 2, true));
			clubs.Add(club);
		
			return clubs;
		}
	}
}
